#!/usr/bin/env python
# vim: set fileencoding=utf-8 :
# Andre Anjos <andre.anjos@idiap.ch>
# Wed 11 May 2011 14:37:07 CEST 

"""Checks if two (or more) score files are consistent between each other.
"""

__epilog__ = """
Examples:

  1. Checks two unsorted score files:

     $ checkModalities.py score-file1.txt score-file2.txt

  2. Checks two score files that are assumed to be sorted already:

     $ checkModalities.py --sorted score-file1.txt score-file2.txt

  To sort score files, you can use shell utilities `sort` and `uniq`:

     $ sort my-score-file.txt | uniq > my-sorted-score-file.txt
"""

import os
import sys

def get_options():
  """Processes user options and arguments, makes sure all is ok."""
  import optparse

  class MyParser(optparse.OptionParser):
    def format_epilog(self, formatter):
      return self.epilog

  usage = 'usage: %s [options] <score-file> [+<score-file>]' % \
      os.path.basename(sys.argv[0])

  parser = MyParser(usage=usage, description=__doc__, epilog=__epilog__)

  parser.add_option('-s', '--sorted', dest="sorted", default=False,
      action="store_true", help="set this flag if you have sorted the input score files already and you don't need this program to do that again (may speed-up comparision a lot if your score files are huge).")

  options, args = parser.parse_args()

  if len(args) < 2:
    parser.error("you should give at least two score files to process")

  return options, args

def main():
  """The main method, just process options and call STK"""
 
  from .. import load_file, checkModalities

  options, args = get_options()

  # compares args[0] to all the others
  print("Loading score file %s..." % args[0])
  d0 = load_file(args[0])
  for k in args[1:]:
    print("Loading score file %s..." % k)
    d = load_file(k)
    if options.sorted:
      print("Comparing previously sorted %s and %s..." % (args[0], k))
    else:
      print("Sorting and comparing %s and %s..." % (args[0], k))
    checkModalities(d0, args[0], d, k, options.sorted)
    print("SUCCESS: Scores from %s and %s can be fused" % (args[0], k))

  sys.exit(0)
